"""Metadata for xkcd_random."""

__all__ = [
    "__title__",
    "__version__",
    "__credits__",
    "__description__",
    "__readme__",
    "__requires_python__",
    "__status__",
]

__title__ = "xkcd-random"
__version__ = "0.1.0"
__credits__ = [{"name": "Matthew Dean Martin", "email": "matthewdeanmartin@gmail.com"}]
__description__ = "Drop in replacment for random that always returns 4 or 4/6"
__readme__ = "README.md"
__requires_python__ = ">=3.8"
__status__ = "1 - Planning"
